@@ -57,7 +57,7 @@ def process(msg) :
     global result_jdict
 
     att_dict['operator'] = 'json_dict'
-    logger, log_stream = slog.set_logging(att_dict['operator'], loglevel=api.config.debug_mode,stream_output=True)
+    logger, log_stream = slog.set_logging(att_dict['operator'], loglevel=api.config.debug_mode)
     logger.info("Process started. Logging level: {}".format(logger.level))
 
     logger.debug('Attributes: {}'.format(str(msg.attributes)))
@@ -90,6 +90,7 @@ def process(msg) :
         ('message.lastBatch' in att_dict and att_dict['message.lastBatch'] == True) or \
         ('batch.index' in att_dict and  att_dict['batch.index'] + 1 == att_dict['batch.number']) or \
         ('storage.fileIndex' in att_dict and att_dict['storage.fileIndex'] + 1 == att_dict['storage.fileCount']) :
+
         msg = api.Message(attributes=att_dict,body=result_jdict)
         api.send(outports[1]['name'], msg)
         logger.info('Msg send to port: {}'.format(outports[1]['name']))
